from logging import getLogger
from pathlib import Path

from .config import CONFIG as _CONFIG
from .util import create_temporary_docker_volume, run_docker_container


LOGGER = getLogger(__name__)
CONFIG = _CONFIG['ocr']


def run_tesseract(client, preprocessing_volume, second_pass_volume) -> None:
    with create_temporary_docker_volume(client) as first_pass_volume:
        run_tesseract_first_pass(client, preprocessing_volume, first_pass_volume)
        run_tesseract_second_pass(client, preprocessing_volume, first_pass_volume, second_pass_volume)


def run_tesseract_first_pass(client, preprocessing_volume, first_pass_volume) -> None:
    LOGGER.info('Running the first pass of Tesseract with all languages')
    volumes = {
        preprocessing_volume.name: {
            'bind': '/input',
            'mode': 'ro',
        },
        first_pass_volume.name: {
            'bind': '/output',
            'mode': 'rw',
        },
    }
    command = [
        'parallel', '--halt', 'now,fail=100%', '--jobs', '25%', '--',
        f'nice -n {CONFIG.getint("niceness")} tesseract {{}} /output/{{/.}} -l {CONFIG["languages"]} '
        '--oem 1 --psm 3 --tessdata-dir /tessdata hocr txt tsv makebox', '::::', '/input/list.txt',
    ]
    run_docker_container(client, 'ahisto/tesseract', command=command, volumes=volumes)


def run_tesseract_second_pass(client, preprocessing_volume, first_pass_volume,
                              second_pass_volume) -> None:
    pass


def run_google_vision_ai(client, postprocessing_volume, google_vision_ai_volume,
                         google_api_key: Path) -> None:
    pass


def combine_results(client, tesseract_volume, google_vision_ai_volume, output_volume):
    pass
